BinaryReader

Struct BinaryReader 

pub struct BinaryReader<'a> { /* private fields */ }

Implementations

Source

impl<'a> BinaryReader<'a>

pub fn new(buffer: &'a [u8]) -> Self

pub unsafe fn from_ptr(ptr: *const u8, size: usize) -> Self

Safety

The caller must ensure that ptr points to a valid block of memory of at least size bytes, and that the memory remains valid for the lifetime 'a.

pub fn from_variable_sized<T>(header: &'a T) -> Self
where T: VariableSized,

pub fn from_payload_of_struct<T>(header: &'a T) -> Self
where T: VariableSized,

pub fn read_fixed_length<T>(&mut self) -> Option<&'a T>

pub fn read<T>(&mut self) -> Option<&'a T>

pub fn skip_bytes(&mut self, bytes: usize) -> bool

pub fn is_empty(&self) -> bool