AcpiRsdt

Struct AcpiRsdt 

#[repr(C, packed(1))]
pub struct AcpiRsdt { pub header: AcpiSdtHeader, }

Fields

header: AcpiSdtHeader

Implementations

Source

impl AcpiRsdt

pub const K_SIGNATURE: AcpiSignature

pub unsafe fn get_entry(&self, index: usize) -> u32

Safety

The caller must ensure that index is within the bounds of the table payload (which is determined by the table length in the header).