pub struct BinaryReader<'a> { /* private fields */ }Implementations
Sourceimpl<'a> BinaryReader<'a>
impl<'a> BinaryReader<'a>
pub fn new(buffer: &'a [u8]) -> Self
Sourcepub unsafe fn from_ptr(ptr: *const u8, size: usize) -> Self
pub unsafe fn from_ptr(ptr: *const u8, size: usize) -> Self
Safety
The caller must ensure that ptr points to a valid block of memory
of at least size bytes, and that the memory remains valid for the
lifetime 'a.